@@ -21,22 +21,15 @@ from distutils.extension import Extension
 from Cython.Distutils import build_ext
 import numpy as np
 
-# Is the default numpy int 32 or 64 bits?
-if np.int_ == np.int32:
-    bits = '32'
-elif np.int_ == np.int64:
-    bits = '64'
-else:
-    raise ValueError("Your OS does not appear to be 32 or 64 bits.")
-
 mod_dir = os.path.dirname(__file__)
-ext_modules = [Extension("move", [os.path.join(mod_dir, "%sbit/move.pyx") % bits],
+ext_modules = [Extension("move", [os.path.join(mod_dir, "move.pyx")],
+               extra_compile_args=["-std=gnu89"],
                include_dirs=[np.get_include()])]
 
 setup(
-  name = 'move',
-  cmdclass = {'build_ext': build_ext},
-  ext_modules = ext_modules
+    name='move',
+    cmdclass={'build_ext': build_ext},
+    ext_modules=ext_modules
 )
 
 os.rename("move.so", os.path.join(mod_dir, "../../move.so"))
