@@ -56,7 +56,7 @@ from numpy cimport NPY_FLOAT32 as NPY_float32
 from numpy cimport NPY_FLOAT64 as NPY_float64
 from numpy cimport (PyArray_EMPTY, PyArray_TYPE, PyArray_NDIM,
                     PyArray_SIZE, PyArray_DIMS, import_array,
-                    PyArray_ArgSort, NPY_QUICKSORT, NPY_CORDER, 
+                    PyArray_ArgSort, NPY_QUICKSORT, NPY_CORDER,
                     PyArray_Ravel, PyArray_FillWithScalar, PyArray_Copy,
                     NPY_BOOL)
 
@@ -94,8 +94,8 @@ else:
 
 cdef extern from "math.h":
     double sqrt(double x)
-    
-PARTSORT_ERR_MSG = "`n` (=%d) must be between 1 and %d, inclusive." 
+
+PARTSORT_ERR_MSG = "`n` (=%d) must be between 1 and %d, inclusive."
 
 include "nanmax.pyx"
 include "nanmin.pyx"
@@ -118,10 +118,11 @@ include "anynan.pyx"
 include "allnan.pyx"
 """
 
-def funcpyx(funcs=funcs, bits=None):
+
+def funcpyx(funcs=funcs):
     for func in funcs:
-        template(funcs[func], bits)
+        template(funcs[func])
     template_path = os.path.dirname(tempmod.__file__)
-    fid = open(os.path.join(template_path, '..', "func/%sbit/func.pyx") % str(bits), 'w')
+    fid = open(os.path.join(template_path, '..', "func/func.pyx"), 'w')
     fid.write(header)
     fid.close()
