@@ -18,7 +18,7 @@ loop[1] = """\
         raise ValueError(PARTSORT_ERR_MSG % (n, nAXIS))
     l = 0
     r = nAXIS - 1
-    with nogil:       
+    with nogil:
         while l < r:
             x = b[k]
             i = l
@@ -36,13 +36,13 @@ loop[1] = """\
             if j < k: l = i
             if k < i: r = j
     return b
-"""        
+"""
 loop[2] = """\
     if nAXIS == 0:
         return b
     if (n < 1) or (n > nAXIS):
         raise ValueError(PARTSORT_ERR_MSG % (n, nAXIS))
-    for iINDEX0 in range(nINDEX0): 
+    for iINDEX0 in range(nINDEX0):
         l = 0
         r = nAXIS - 1
         while l < r:
@@ -104,7 +104,7 @@ floats['top'] = """
 @cython.wraparound(False)
 def NAME_NDIMd_DTYPE_axisAXIS(np.ndarray[np.DTYPE_t, ndim=NDIM] a, int n):
     "Partial sort of NDIMd array with dtype=DTYPE along axis=AXIS."
-    cdef np.npy_intp i, j = 0, l, r, k = n-1 
+    cdef np.npy_intp i, j = 0, l, r, k = n-1
     cdef np.DTYPE_t x, tmp
     cdef np.ndarray[np.DTYPE_t, ndim=NDIM] b = PyArray_Copy(a)
 """
@@ -114,7 +114,7 @@ floats['loop'] = loop
 # Int dtypes (not axis=None) ------------------------------------------------
 
 ints = deepcopy(floats)
-ints['dtypes'] = INT_DTYPES 
+ints['dtypes'] = INT_DTYPES
 
 # Slow, unaccelerated ndim/dtype --------------------------------------------
 
@@ -133,13 +133,13 @@ partsort['slow'] = slow
 partsort['templates'] = {}
 partsort['templates']['float'] = floats
 partsort['templates']['int'] = ints
-partsort['pyx_file'] = 'func/%sbit/partsort.pyx'
+partsort['pyx_file'] = 'func/partsort.pyx'
 
 partsort['main'] = '''"partsort auto-generated from template"
 # Select smallest k elements code used for inner loop of partsort method:
 # http://projects.scipy.org/numpy/attachment/ticket/1213/quickselect.pyx
 # (C) 2009 Sturla Molden
-# SciPy license 
+# SciPy license
 #
 # From the original C function (code in public domain) in:
 #   Fast median search: an ANSI C implementation
@@ -156,7 +156,7 @@ partsort['main'] = '''"partsort auto-generated from template"
 def partsort(arr, n, axis=-1):
     """
     Partial sorting of array elements along given axis.
-    
+
     A partially sorted array is one in which the `n` smallest values appear
     (in any order) in the first `n` elements. The remaining largest elements
     are also unordered. Due to the algorithm used (Wirth's method), the nth
@@ -173,7 +173,7 @@ def partsort(arr, n, axis=-1):
     ----------
     arr : array_like
         Input array. If `arr` is not an array, a conversion is attempted.
-    n : int    
+    n : int
         The `n` smallest elements will appear (unordered) in the first `n`
         elements of the output array.
     axis : {int, None}, optional
@@ -185,11 +185,11 @@ def partsort(arr, n, axis=-1):
     y : ndarray
         A partially sorted copy of the input array where the `n` smallest
         elements will appear (unordered) in the first `n` elements.
-        
+
     See Also
     --------
     bottleneck.argpartsort: Indices that would partially sort an array
-    
+
     Notes
     -----
     Unexpected results may occur if the input array contains NaN.
@@ -199,14 +199,20 @@ def partsort(arr, n, axis=-1):
     Create a numpy array:
 
     >>> a = np.array([1, 0, 3, 4, 2])
-    
+
     Partially sort array so that the first 3 elements are the smallest 3
     elements (note, as in this example, that the smallest 3 elements may not
     be sorted):
 
     >>> bn.partsort(a, n=3)
     array([1, 0, 2, 4, 3])
-    
+
+    Now partially sort array so that the last 2 elements are the largest 2
+    elements:
+
+    >>> bn.partsort(a, n=a.shape[0]-2)
+    array([1, 0, 2, 3, 4])
+
     """
     func, arr = partsort_selector(arr, axis)
     return func(arr, n)
@@ -214,7 +220,7 @@ def partsort(arr, n, axis=-1):
 def partsort_selector(arr, axis):
     """
     Return partsort function and array that matches `arr` and `axis`.
-    
+
     Under the hood Bottleneck uses a separate Cython function for each
     combination of ndim, dtype, and axis. A lot of the overhead in
     bn.partsort() is in checking that `axis` is within range, converting `arr`
@@ -230,7 +236,7 @@ def partsort_selector(arr, axis):
         Input array. If `arr` is not an array, a conversion is attempted.
     axis : {int, None}
         Axis along which to partially sort.
-    
+
     Returns
     -------
     func : function
@@ -246,13 +252,13 @@ def partsort_selector(arr, axis):
     Create a numpy array:
 
     >>> arr = np.array([1, 0, 3, 4, 2])
-    
+
     Obtain the function needed to partially sort `arr` along axis=0:
 
     >>> func, a = bn.func.partsort_selector(arr, axis=0)
     >>> func
     <function partsort_1d_int64_axis0>
-    
+
     Use the returned function and array to partially sort:
 
     >>> func(a, n=3)
@@ -262,7 +268,7 @@ def partsort_selector(arr, axis):
     cdef np.ndarray a
     if type(arr) is np.ndarray:
         a = arr
-    else:    
+    else:
         a = np.array(arr, copy=False)
     cdef tuple key
     cdef int ndim = PyArray_NDIM(a)
@@ -286,4 +292,4 @@ def partsort_selector(arr, axis):
             tup = (str(ndim), str(a.dtype), str(axis))
             raise TypeError("Unsupported ndim/dtype/axis (%s/%s/%s)." % tup)
     return func, a
-'''   
+'''
